@@ -33,8 +33,6 @@
 #include <unistd.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include "libedataserver/e-xml-hash-utils.h"
 #include "libedataserver/e-url.h"
 #include <libedata-cal/e-cal-backend-cache.h>
@@ -114,7 +112,7 @@ static ECalBackendClass *parent_class = NULL;
 #define CURSOR_ITEM_LIMIT 100
 #define CURSOR_ICALID_LIMIT 500
 
-static guint get_cache_refresh_interval (ECalBackendGroupwise *cbgw);
+static guint get_cache_refresh_interval (void);
 
 EGwConnection *
 e_cal_backend_groupwise_get_connection (ECalBackendGroupwise *cbgw) {
@@ -299,7 +297,7 @@ populate_cache (ECalBackendGroupwise *cbgw)
 		e_gw_connection_destroy_cursor (priv->cnc, priv->container_id, cursor);
 		g_object_unref (filter[i]);
 	}
-	e_cal_backend_notify_view_progress (E_CAL_BACKEND (cbgw), "", 100);
+	e_cal_backend_notify_view_done (E_CAL_BACKEND (cbgw), GNOME_Evolution_Calendar_Success);
 
 	g_mutex_unlock (mutex);
 	return E_GW_CONNECTION_STATUS_OK;
@@ -419,8 +417,8 @@ get_deltas (gpointer handle)
 	for (; item_list != NULL; item_list = g_list_next(item_list)) {
 		EGwItem *item = NULL;
 		ECalComponent *modified_comp = NULL, *cache_comp = NULL;
-		char *cache_comp_str = NULL, *modif_comp_str;
-		const char *uid, *rid = NULL;
+		char *cache_comp_str = NULL, *modif_comp_str, *rid = NULL;
+		const char *uid;
 		int r_key;
 
 		item = E_GW_ITEM(item_list->data);
@@ -442,6 +440,7 @@ get_deltas (gpointer handle)
 		e_cal_backend_notify_object_modified (E_CAL_BACKEND (cbgw), cache_comp_str, modif_comp_str);
 		g_free (modif_comp_str);
 		g_free (cache_comp_str);
+		g_free (rid);
 		cache_comp_str = NULL;
 		e_cal_backend_cache_put_component (cache, modified_comp);
 
@@ -455,7 +454,7 @@ get_deltas (gpointer handle)
 	current_time = icaltime_as_timet_with_zone (temp, icaltimezone_get_utc_timezone ());
 	gmtime_r (&current_time, &tm);
 
-	time_interval = get_cache_refresh_interval (cbgw) / 60000;
+	time_interval = get_cache_refresh_interval () / 60000;
 	
 	if (attempts) {
 		tm.tm_min += (time_interval * g_ascii_strtod (attempts, NULL));
@@ -651,28 +650,17 @@ get_deltas (gpointer handle)
 }
 
 static guint
-get_cache_refresh_interval (ECalBackendGroupwise *cbgw)
+get_cache_refresh_interval (void)
 {
 	guint time_interval;
 	const char *time_interval_string = NULL;
-	char *temp = NULL;
-	ECalBackend *backend = E_CAL_BACKEND (cbgw);
-	ESource *source;
 	
 	time_interval = CACHE_REFRESH_INTERVAL;
-	source = e_cal_backend_get_source (backend);
-	
 	time_interval_string = g_getenv ("GETQM_TIME_INTERVAL");
-	
-	if (!time_interval_string)
-		time_interval_string = temp = e_source_get_duped_property (source, "refresh");
-
 	if (time_interval_string) {
 		time_interval = g_ascii_strtod (time_interval_string, NULL);
 		time_interval *= (60*1000);
 	}
-
-	g_free (temp);
 		
 	return time_interval;
 }
@@ -696,7 +684,7 @@ delta_thread (gpointer data)
 			break;
 
 		g_get_current_time (&timeout);
-		g_time_val_add (&timeout, get_cache_refresh_interval (cbgw) * 1000);
+		g_time_val_add (&timeout, get_cache_refresh_interval () * 1000);
 		g_cond_timed_wait (priv->dlock->cond, priv->dlock->mutex, &timeout);
 		
 		if (priv->dlock->exit) 
@@ -848,7 +836,7 @@ cache_init (ECalBackendGroupwise *cbgw)
 			int time_interval;
 			char *utc_str;
 
-			time_interval = get_cache_refresh_interval (cbgw);
+			time_interval = get_cache_refresh_interval ();
 			utc_str = (char *) e_gw_connection_get_server_time (priv->cnc);
 			e_cal_backend_cache_set_marker (priv->cache);
 			e_cal_backend_cache_put_server_utc_time (priv->cache, utc_str);
@@ -1377,9 +1365,6 @@ e_cal_backend_groupwise_open (ECalBackendSync *backend, EDataCal *cal, gboolean
 				     mangled_uri,
 				     NULL);
 	g_free (mangled_uri);
-	if (priv->local_attachments_store)
-		g_free (priv->local_attachments_store);
-
 	priv->local_attachments_store =
 		g_filename_to_uri (filename, NULL, NULL);
 	g_free (filename);
@@ -1801,7 +1786,7 @@ e_cal_backend_groupwise_compute_changes (ECalBackendGroupwise *cbgw, const char
 	cache = cbgw->priv->cache;
 
 	/* FIXME Will this always work? */
-	unescaped_uri = gnome_vfs_unescape_string (cbgw->priv->uri, "");
+	unescaped_uri = g_uri_unescape_string (cbgw->priv->uri, "");
 	filename = g_strdup_printf ("%s-%s.db", unescaped_uri, change_id);
 	ehash = e_xmlhash_new (filename);
 	g_free (filename);
@@ -2106,7 +2091,8 @@ e_cal_backend_groupwise_modify_object (ECalBackendSync *backend, EDataCal *cal,
 	ECalComponent *comp, *cache_comp = NULL;
 	EGwConnectionStatus status;
 	EGwItem *item, *cache_item;
-	const char *uid = NULL, *rid = NULL;
+	const char *uid = NULL;
+	char *rid = NULL;
 
 	*old_object = NULL;
 	cbgw = E_CAL_BACKEND_GROUPWISE (backend);
@@ -2137,6 +2123,7 @@ e_cal_backend_groupwise_modify_object (ECalBackendSync *backend, EDataCal *cal,
 		cache_comp = e_cal_backend_cache_get_component (priv->cache, uid, rid);
 		if (!cache_comp) {
 			g_message ("CRITICAL : Could not find the object in cache");
+			g_free (rid);
 			return GNOME_Evolution_Calendar_ObjectNotFound;
 		}
 
@@ -2158,6 +2145,7 @@ e_cal_backend_groupwise_modify_object (ECalBackendSync *backend, EDataCal *cal,
 			if (status != E_GW_CONNECTION_STATUS_OK) {
 				g_object_unref (comp);
 				g_object_unref (cache_comp);
+				g_free (rid);
 				return GNOME_Evolution_Calendar_OtherError;
 			}
 
@@ -2183,6 +2171,7 @@ e_cal_backend_groupwise_modify_object (ECalBackendSync *backend, EDataCal *cal,
 				if (status != E_GW_CONNECTION_STATUS_OK) {
 					g_object_unref (comp);
 					g_object_unref (cache_comp);
+					g_free (rid);
 					return GNOME_Evolution_Calendar_OtherError;
 				}
 				e_cal_backend_cache_put_component (priv->cache, comp);
@@ -2201,6 +2190,7 @@ e_cal_backend_groupwise_modify_object (ECalBackendSync *backend, EDataCal *cal,
 		if (status != E_GW_CONNECTION_STATUS_OK) {
 			g_object_unref (comp);
 			g_object_unref (cache_comp);
+			g_free (rid);
 			return GNOME_Evolution_Calendar_OtherError;
 		}
 		/* if successful, update the cache */
@@ -2217,6 +2207,7 @@ e_cal_backend_groupwise_modify_object (ECalBackendSync *backend, EDataCal *cal,
 	*old_object = e_cal_component_get_as_string (cache_comp);
 	g_object_unref (cache_comp);
 	g_object_unref (comp);
+	g_free (rid);
 	return GNOME_Evolution_Calendar_Success;
 }
 
@@ -2651,7 +2642,8 @@ send_object (ECalBackendGroupwise *cbgw, EDataCal *cal, icalcomponent *icalcomp,
 	ECalComponent *comp, *found_comp = NULL;
 	ECalBackendGroupwisePrivate *priv;
 	ECalBackendSyncStatus status = GNOME_Evolution_Calendar_OtherError;
-	const char *uid = NULL, *rid = NULL;
+	const char *uid = NULL;
+	char *rid = NULL;
 
 	priv = cbgw->priv;
 
@@ -2661,6 +2653,8 @@ send_object (ECalBackendGroupwise *cbgw, EDataCal *cal, icalcomponent *icalcomp,
 
 	e_cal_component_get_uid (comp, (const char **) &uid);
 	found_comp = e_cal_backend_cache_get_component (priv->cache, uid, rid);
+	g_free (rid);
+	rid = NULL;
 
 	if (!found_comp) {
 		g_object_unref (comp);
