@@ -115,6 +115,8 @@ static gboolean        is_frozen             (CamelFolder *folder);
 static gboolean        folder_changed        (CamelObject *object,
 					      gpointer event_data);
 
+static CamelFolderQuotaInfo *get_quota_info  (CamelFolder *folder);
+
 static void
 camel_folder_class_init (CamelFolderClass *camel_folder_class)
 {
@@ -155,6 +157,7 @@ camel_folder_class_init (CamelFolderClass *camel_folder_class)
 	camel_folder_class->freeze = freeze;
 	camel_folder_class->thaw = thaw;
 	camel_folder_class->is_frozen = is_frozen;
+	camel_folder_class->get_quota_info = get_quota_info;
 
 	/* virtual method overload */
 	camel_object_class->getv = folder_getv;
@@ -307,7 +310,7 @@ folder_getv(CamelObject *object, CamelException *ex, CamelArgGetV *args)
 	CamelFolder *folder = (CamelFolder *)object;
 	int i;
 	guint32 tag;
-	int unread = -1, deleted = 0, junked = 0, visible = 0, count = -1;
+	int unread = -1, deleted = 0, junked = 0, junked_not_deleted = 0, visible = 0, count = -1;
 
 	for (i = 0; i < args->argc; i++) {
 		CamelArgGet *arg = &args->argv[i];
@@ -341,6 +344,7 @@ folder_getv(CamelObject *object, CamelException *ex, CamelArgGetV *args)
 		case CAMEL_FOLDER_ARG_UNREAD:
 		case CAMEL_FOLDER_ARG_DELETED:
 		case CAMEL_FOLDER_ARG_JUNKED:
+		case CAMEL_FOLDER_ARG_JUNKED_NOT_DELETED:
 		case CAMEL_FOLDER_ARG_VISIBLE:
 			/* This is so we can get the values atomically, and also so we can calculate them only once */
 			if (unread == -1) {
@@ -358,8 +362,11 @@ folder_getv(CamelObject *object, CamelException *ex, CamelArgGetV *args)
 							unread++;
 						if (flags & CAMEL_MESSAGE_DELETED)
 							deleted++;
-						if (flags & CAMEL_MESSAGE_JUNK)
+						if (flags & CAMEL_MESSAGE_JUNK) {
 							junked++;
+							if (! (flags & CAMEL_MESSAGE_DELETED))
+								junked_not_deleted++;
+						}
 						if ((flags & (CAMEL_MESSAGE_DELETED|CAMEL_MESSAGE_JUNK)) == 0)
 							visible++;
 						camel_message_info_free(info);
@@ -377,6 +384,9 @@ folder_getv(CamelObject *object, CamelException *ex, CamelArgGetV *args)
 			case CAMEL_FOLDER_ARG_JUNKED:
 				count = junked;
 				break;
+			case CAMEL_FOLDER_ARG_JUNKED_NOT_DELETED:
+				count = junked_not_deleted;
+				break;
 			case CAMEL_FOLDER_ARG_VISIBLE:
 				count = visible;
 				break;
@@ -1625,6 +1635,95 @@ camel_folder_is_frozen (CamelFolder *folder)
 	return CF_CLASS (folder)->is_frozen (folder);
 }
 
+static CamelFolderQuotaInfo *
+get_quota_info (CamelFolder *folder)
+{
+	return NULL;
+}
+
+/**
+ * camel_folder_get_quota_info:
+ * @folder: a #CamelFolder object
+ *
+ * Returns list of known quota(s) for the folder.
+ **/
+CamelFolderQuotaInfo *
+camel_folder_get_quota_info (CamelFolder *folder)
+{
+	g_return_val_if_fail (CAMEL_IS_FOLDER (folder), NULL);
+
+	return CF_CLASS (folder)->get_quota_info (folder);
+}
+
+/**
+ * camel_folder_quota_info_new:
+ * @name: Name of the quota.
+ * @used: Current usage of the quota.
+ * @total: Total available size of the quota.
+ *
+ * Returns newly allocated #CamelFolderQuotaInfo structure with initialized values
+ * based on the parameters, with next member set to NULL.
+ **/
+CamelFolderQuotaInfo *
+camel_folder_quota_info_new (const char *name, guint64 used, guint64 total)
+{
+	CamelFolderQuotaInfo *info;
+
+	info = g_malloc0 (sizeof (CamelFolderQuotaInfo));
+	info->name = g_strdup (name);
+	info->used = used;
+	info->total = total;
+	info->next = NULL;
+
+	return info;
+}
+
+/**
+ * camel_folder_quota_info_clone:
+ * @info: a #CamelFolderQuotaInfo object to clone.
+ *
+ * Makes a copy of the given info and all next-s.
+ **/
+CamelFolderQuotaInfo *
+camel_folder_quota_info_clone (const CamelFolderQuotaInfo *info)
+{
+	CamelFolderQuotaInfo *clone = NULL, *last = NULL;
+	const CamelFolderQuotaInfo *iter;
+
+	for (iter = info; iter != NULL; iter = iter->next) {
+		CamelFolderQuotaInfo *n = camel_folder_quota_info_new (iter->name, iter->used, iter->total);
+
+		if (last)
+			last->next = n;
+		else
+			clone = n;
+
+		last = n;
+	}
+
+	return clone;
+}
+
+/**
+ * camel_folder_quota_info_free:
+ * @info: a #CamelFolderQuotaInfo object to free.
+ *
+ * Frees this and all next objects.
+ **/
+void
+camel_folder_quota_info_free (CamelFolderQuotaInfo *info)
+{
+	CamelFolderQuotaInfo *next = info;
+
+	while (next) {
+		info = next;
+		next = next->next;
+
+		g_free (info->name);
+		g_free (info);
+	}
+}
+
 struct _folder_filter_msg {
 	CamelSessionThreadMsg msg;
 
